@@ -38,7 +38,7 @@
  * Must be free()'d by caller.
  */
 char *
-datetime_get_current_as_string ();
+datetime_get_current_as_string (void);
 
 /**
  * @}
