@@ -27,15 +27,19 @@
 /**
  * Creates and returns an open project dialog.
  */
-GtkDialog * dialogs_get_open_project_dialog (GtkWindow * parent);
+GtkDialog *
+dialogs_get_open_project_dialog (
+  GtkWindow * parent);
 
 /**
  * Creates and returns the overwrite plugin dialog.
  */
-GtkDialog * dialogs_get_overwrite_plugin_dialog (
+GtkDialog *
+dialogs_get_overwrite_plugin_dialog (
   GtkWindow * parent);
 
-GtkDialog * dialogs_get_error_instantiating_plugin_dialog (
+GtkDialog *
+dialogs_get_error_instantiating_plugin_dialog (
   GtkWindow * parent);
 
 #endif
