@@ -38,6 +38,7 @@
 #include "audio/metronome.h"
 #include "audio/midi.h"
 #include "audio/mixer.h"
+#include "audio/pool.h"
 #include "audio/routing.h"
 #include "audio/sample_playback.h"
 #include "audio/sample_processor.h"
@@ -58,18 +59,26 @@
 #include <jack/midiport.h>
 #endif
 
- void
-engine_update_frames_per_tick (int beats_per_bar,
-                               int bpm,
-                               int sample_rate)
+/**
+ * Updates frames per tick based on the time sig,
+ * the BPM, and the sample rate
+ */
+void
+engine_update_frames_per_tick (
+  AudioEngine *       self,
+  const int           beats_per_bar,
+  const bpm_t         bpm,
+  const sample_rate_t sample_rate)
 {
-  AUDIO_ENGINE->frames_per_tick =
-    (sample_rate * 60.f * beats_per_bar) /
-    (bpm * TRANSPORT->ticks_per_bar);
+  self->frames_per_tick =
+    (int)
+    (((float) sample_rate * 60.f *
+       (float) beats_per_bar) /
+    (bpm * (float) TRANSPORT->ticks_per_bar));
 
   /* update positions */
   transport_update_position_frames (
-    &AUDIO_ENGINE->transport);
+    &self->transport);
 
   for (int i = 0; i < TRACKLIST->num_tracks; i++)
     {
@@ -111,14 +120,14 @@ init_audio (
 
   control_room_init (CONTROL_ROOM, loading);
 
-  if (loading)
-    {
+  /*if (loading)*/
+    /*{*/
       /*stereo_ports_init_loaded (self->stereo_in);*/
       /*stereo_ports_init_loaded (self->monitor_out);*/
-    }
-  else
-    {
-    }
+    /*}*/
+  /*else*/
+    /*{*/
+    /*}*/
 }
 
 /**
@@ -265,8 +274,6 @@ engine_init (
   /* init audio */
   init_audio (self, loading);
 
-  sample_processor_init (SAMPLE_PROCESSOR);
-
   /* connect fader to monitor out */
   stereo_ports_connect (
     MONITOR_FADER->stereo_out,
@@ -322,12 +329,24 @@ engine_init (
   self->buf_size_set = false;
 
   metronome_init (METRONOME);
+  sample_processor_init (SAMPLE_PROCESSOR);
 
   /* connect the sample processor to the engine
    * output */
   stereo_ports_connect (
     SAMPLE_PROCESSOR->stereo_out,
     self->control_room.monitor_fader.stereo_in, 1);
+
+  /** init audio pool */
+  if (loading)
+    {
+      audio_pool_init_loaded (self->pool);
+    }
+  else
+    {
+      self->pool =
+        audio_pool_new ();
+    }
 }
 
 /**
@@ -367,7 +386,7 @@ engine_is_port_own (
 void
 engine_realloc_port_buffers (
   AudioEngine * self,
-  int           nframes)
+  nframes_t     nframes)
 {
   int i, j;
 
@@ -417,31 +436,32 @@ engine_realloc_port_buffers (
   AUDIO_ENGINE->nframes = nframes;
 }
 
-void
-audio_engine_close (AudioEngine * self)
-{
-  g_message ("closing audio engine...");
+/*void*/
+/*audio_engine_close (*/
+  /*AudioEngine * self)*/
+/*{*/
+  /*g_message ("closing audio engine...");*/
 
-  switch (self->audio_backend)
-    {
-    case AUDIO_BACKEND_DUMMY:
-      break;
-#ifdef HAVE_JACK
-    case AUDIO_BACKEND_JACK:
-      jack_client_close (AUDIO_ENGINE->client);
-      break;
-#endif
-#ifdef HAVE_PORT_AUDIO
-    case AUDIO_BACKEND_PORT_AUDIO:
-      pa_terminate (AUDIO_ENGINE);
-      break;
-#endif
-    case NUM_AUDIO_BACKENDS:
-    default:
-      g_warn_if_reached ();
-      break;
-    }
-}
+  /*switch (self->audio_backend)*/
+    /*{*/
+    /*case AUDIO_BACKEND_DUMMY:*/
+      /*break;*/
+/*#ifdef HAVE_JACK*/
+    /*case AUDIO_BACKEND_JACK:*/
+      /*jack_client_close (AUDIO_ENGINE->client);*/
+      /*break;*/
+/*#endif*/
+/*#ifdef HAVE_PORT_AUDIO*/
+    /*case AUDIO_BACKEND_PORT_AUDIO:*/
+      /*pa_terminate (AUDIO_ENGINE);*/
+      /*break;*/
+/*#endif*/
+    /*case NUM_AUDIO_BACKENDS:*/
+    /*default:*/
+      /*g_warn_if_reached ();*/
+      /*break;*/
+    /*}*/
+/*}*/
 
 /**
  * Clears the underlying backend's output buffers.
@@ -449,7 +469,7 @@ audio_engine_close (AudioEngine * self)
 static void
 clear_output_buffers (
   AudioEngine * self,
-  int           nframes)
+  nframes_t     nframes)
 {
   switch (self->audio_backend)
     {
@@ -622,7 +642,7 @@ static void
 find_and_queue_metronome (
   const Position * start_pos,
   const Position * end_pos,
-  const int        loffset)
+  const nframes_t  loffset)
 {
   /* find each bar / beat change from start
    * to finish */
@@ -637,7 +657,7 @@ find_and_queue_metronome (
 
 
   Position bar_pos;
-  int bar_offset;
+  nframes_t bar_offset;
   for (int i =
          start_pos->beats == 1 &&
          start_pos->sixteenths == 1 &&
@@ -650,7 +670,8 @@ find_and_queue_metronome (
       position_set_to_bar (
         &bar_pos, i + 1);
       bar_offset =
-        bar_pos.frames - start_pos->frames;
+        (nframes_t)
+        (bar_pos.frames - start_pos->frames);
       sample_processor_queue_metronome (
         SAMPLE_PROCESSOR,
         METRONOME_TYPE_EMPHASIS,
@@ -666,7 +687,7 @@ find_and_queue_metronome (
     num_beats_after--;
 
   Position beat_pos;
-  int beat_offset;
+  nframes_t beat_offset;
   for (int i =
          start_pos->sixteenths == 1 &&
          start_pos->ticks == 0 ?
@@ -684,7 +705,8 @@ find_and_queue_metronome (
       if (beat_pos.beats != 1)
         {
           beat_offset =
-            beat_pos.frames - start_pos->frames;
+            (nframes_t)
+            (beat_pos.frames - start_pos->frames);
           sample_processor_queue_metronome (
             SAMPLE_PROCESSOR,
             METRONOME_TYPE_NORMAL,
@@ -700,18 +722,21 @@ find_and_queue_metronome (
  */
 static void
 queue_metronome_events (
- AudioEngine * self,
- const int     loffset,
- const int     nframes)
+ AudioEngine *   self,
+ const nframes_t loffset,
+ const nframes_t nframes)
 {
-  Position pos, bar_pos, beat_pos, unlooped_playhead;
+  Position pos, bar_pos, beat_pos,
+           unlooped_playhead;
   position_init (&bar_pos);
   position_init (&beat_pos);
   position_set_to_pos (&pos, PLAYHEAD);
-  position_set_to_pos (&unlooped_playhead, PLAYHEAD);
+  position_set_to_pos (
+    &unlooped_playhead, PLAYHEAD);
   transport_position_add_frames (
     TRANSPORT, &pos, nframes);
-  position_add_frames (&unlooped_playhead, nframes);
+  position_add_frames (
+    &unlooped_playhead, nframes);
   int loop_crossed =
     unlooped_playhead.frames !=
     pos.frames;
@@ -728,6 +753,7 @@ queue_metronome_events (
       find_and_queue_metronome (
         &TRANSPORT->loop_start_pos, &pos,
         loffset +
+          (nframes_t)
           (TRANSPORT->loop_end_pos.frames -
            PLAYHEAD->frames));
     }
@@ -751,7 +777,7 @@ queue_metronome_events (
 int
 engine_process (
   AudioEngine * self,
-  uint32_t      _nframes)
+  nframes_t     _nframes)
 {
   /* Clear output buffers just in case we have to
    * return early */
@@ -759,17 +785,15 @@ engine_process (
 
   if (!g_atomic_int_get (&self->run))
     {
-      g_message ("ENGINE NOT RUNNING");
+      /*g_message ("ENGINE NOT RUNNING");*/
       return 0;
     }
 
   /*count++;*/
   /*self->cycle = count;*/
 
-  uint32_t nframes = _nframes;
-
   /* run pre-process code */
-  engine_process_prepare (self, nframes);
+  engine_process_prepare (self, _nframes);
 
   if (AUDIO_ENGINE->skip_cycle)
     {
@@ -778,16 +802,18 @@ engine_process (
     }
 
   /* puts MIDI in events in the MIDI in port */
-  receive_midi_events (self, nframes, 1);
+  receive_midi_events (self, _nframes, 1);
 
-  long route_latency = 0;
+  nframes_t route_latency = 0;
   GraphNode * start_node;
-  int i, num_samples;
+  int i;
+  nframes_t num_samples;
+  nframes_t nframes = _nframes;
   while (self->remaining_latency_preroll > 0)
     {
       num_samples =
         MIN (
-          nframes, self->remaining_latency_preroll);
+          _nframes, self->remaining_latency_preroll);
       for (i = 0;
            i < MIXER->router.graph2->
              n_init_triggers;
@@ -877,7 +903,7 @@ engine_process (
   /*g_message ("end====================");*/
 
   /* run post-process code */
-  engine_post_process (self);
+  engine_post_process (self, nframes);
 
   /*
    * processing finished, return 0 (OK)
@@ -890,7 +916,8 @@ engine_process (
  */
 void
 engine_post_process (
-  AudioEngine * self)
+  AudioEngine * self,
+  const nframes_t nframes)
 {
   zix_sem_post (&self->port_operation_lock);
 
@@ -898,7 +925,7 @@ engine_post_process (
     {
       /* fill in the external buffers */
       engine_fill_out_bufs (
-        self, self->nframes);
+        self, nframes);
     }
 
   /* stop panicking */
@@ -913,14 +940,15 @@ engine_post_process (
       self->remaining_latency_preroll == 0)
     {
       transport_add_to_playhead (
-        TRANSPORT, self->nframes);
+        TRANSPORT, nframes);
       if (self->audio_backend ==
             AUDIO_BACKEND_JACK &&
           self->transport_type ==
             AUDIO_ENGINE_JACK_TIMEBASE_MASTER)
         {
           jack_transport_locate (
-            self->client, PLAYHEAD->frames);
+            self->client,
+            (jack_nframes_t) PLAYHEAD->frames);
         }
     }
 
@@ -941,15 +969,15 @@ engine_post_process (
  */
 void
 engine_fill_out_bufs (
-  AudioEngine * self,
-  int           nframes)
+  AudioEngine *   self,
+  const nframes_t nframes)
 {
   switch (self->audio_backend)
     {
     case AUDIO_BACKEND_DUMMY:
       break;
     case AUDIO_BACKEND_ALSA:
-#ifdef __linux__
+#ifdef HAVE_ALSA
       engine_alsa_fill_out_bufs (self, nframes);
 #endif
       break;
@@ -972,14 +1000,15 @@ engine_fill_out_bufs (
  * Closes any connections and free's data.
  */
 void
-engine_tear_down ()
+engine_tear_down (
+  AudioEngine * self)
 {
   g_message ("tearing down audio engine...");
 
 #ifdef HAVE_JACK
-  if (AUDIO_ENGINE->audio_backend ==
+  if (self->audio_backend ==
         AUDIO_BACKEND_JACK)
-    jack_tear_down ();
+    jack_tear_down (self);
 #endif
 
   /* TODO free data */
