@@ -76,8 +76,8 @@ void
 midi_track_fill_midi_events (
   Track * track,
   const long        g_start_frames,
-  const int         local_start_frame,
-  uint32_t          nframes,
+  const nframes_t local_start_frame,
+  nframes_t     nframes,
   MidiEvents *      midi_events)
 {
   int i, j, k, jj, num_loops;
@@ -102,7 +102,7 @@ midi_track_fill_midi_events (
       TRANSPORT, g_start_frames, nframes);
   int loop_point_met = g_end_frames < g_start_frames;
   /*int diff_from_loop_start;*/
-  int diff_to_loop_end;
+  unsigned int diff_to_loop_end;
 
   if (loop_point_met)
     {
@@ -110,8 +110,9 @@ midi_track_fill_midi_events (
         /*g_end_frames -*/
         /*TRANSPORT->loop_start_pos.frames;*/
       diff_to_loop_end =
-        TRANSPORT->loop_end_pos.frames -
-        g_start_frames;
+        (unsigned int)
+        (TRANSPORT->loop_end_pos.frames -
+         g_start_frames);
       /*g_message (*/
         /*"loop point met for %s at %ld"*/
         /*"(diff from loop start %d | "*/
@@ -268,10 +269,11 @@ midi_track_fill_midi_events (
                         /*diff_to_loop_end - 1);*/
                       midi_events_add_note_off (
                         midi_events,
-                        midi_note->region->
-                          lane->midi_ch,
+                        midi_region_get_midi_ch (
+                          midi_note->region),
                         midi_note->val,
-                        diff_to_loop_end - 1,
+                        (midi_time_t)
+                        (diff_to_loop_end - 1),
                         1);
                     }
                 }
@@ -309,11 +311,12 @@ midi_track_fill_midi_events (
                               /*local_pos);*/
                           midi_events_add_note_off (
                             midi_events,
-                            midi_note->region->
-                              lane->midi_ch,
+                            midi_region_get_midi_ch (
+                              midi_note->region),
                             midi_note->val,
-                            region_end_adjusted -
-                              local_pos,
+                            (midi_time_t)
+                            (region_end_adjusted -
+                              local_pos),
                             1);
                         }
                     }
@@ -370,11 +373,12 @@ midi_track_fill_midi_events (
                               /*g_start_frames);*/
                           midi_events_add_note_off (
                             midi_events,
-                            midi_note->region->
-                              lane->midi_ch,
+                            midi_region_get_midi_ch (
+                              midi_note->region),
                             midi_note->val,
-                            (region_end_frames - 1) -
-                              g_start_frames,
+                            (midi_time_t)
+                            ((region_end_frames - 1) -
+                              g_start_frames),
                             1);
                         }
                     }
@@ -416,12 +420,13 @@ midi_track_fill_midi_events (
                            */
                           midi_events_add_note_off (
                             midi_events,
-                            midi_note->region->
-                              lane->midi_ch,
+                            midi_region_get_midi_ch (
+                              midi_note->region),
                             midi_note->val,
-                            (loop_end_adjusted -
+                            (midi_time_t)
+                            ((loop_end_adjusted -
                               local_pos) +
-                              diff_to_loop_end,
+                              diff_to_loop_end),
                             1);
                         }
                     }
@@ -461,13 +466,14 @@ midi_track_fill_midi_events (
                         /*midi_note->start_pos.frames);*/
                       midi_events_add_note_on (
                         midi_events,
-                        midi_note->region->
-                          lane->midi_ch,
+                        midi_region_get_midi_ch (
+                          midi_note->region),
                         midi_note->val,
                         midi_note->vel->vel,
-                        (loop_end_adjusted -
+                        (midi_time_t)
+                        ((loop_end_adjusted -
                           local_pos) +
-                          mn_start_frames,
+                          mn_start_frames),
                         1);
                     }
                   /* check for note on event in the
@@ -485,13 +491,14 @@ midi_track_fill_midi_events (
                         /*diff_to_loop_end);*/
                       midi_events_add_note_on (
                         midi_events,
-                        midi_note->region->
-                          lane->midi_ch,
+                        midi_region_get_midi_ch (
+                          midi_note->region),
                         midi_note->val,
                         midi_note->vel->vel,
-                        (mn_start_frames -
+                        (midi_time_t)
+                        ((mn_start_frames -
                            local_pos) +
-                         diff_to_loop_end,
+                         diff_to_loop_end),
                         1);
                     }
 
@@ -514,13 +521,13 @@ midi_track_fill_midi_events (
                         /*midi_note->end_pos.frames);*/
                       midi_events_add_note_off (
                         midi_events,
-                        midi_note->region->
-                          lane->midi_ch,
+                        midi_region_get_midi_ch (
+                          midi_note->region),
                         midi_note->val,
-                        /*start_frame +*/
-                        (mn_end_frames -
+                        (midi_time_t)
+                        ((mn_end_frames -
                            local_pos) +
-                          diff_to_loop_end,
+                          diff_to_loop_end),
                         1);
                     }
                 }
