@@ -116,6 +116,7 @@ track_init (Track * self)
 {
   self->visible = 1;
   self->handle_pos = 1;
+  self->midi_ch = 1;
   track_add_lane (self);
 }
 
@@ -409,8 +410,8 @@ track_set_recording (Track *   track,
       return;
     }
 
-  if (recording)
-    {
+  /*if (recording)*/
+    /*{*/
       /* FIXME just enable the connections */
       /*port_connect (*/
         /*AUDIO_ENGINE->stereo_in->l,*/
@@ -421,9 +422,9 @@ track_set_recording (Track *   track,
       /*port_connect (*/
         /*AUDIO_ENGINE->midi_in,*/
         /*channel->midi_in, 1);*/
-    }
-  else
-    {
+    /*}*/
+  /*else*/
+    /*{*/
       /* FIXME just disable the connections */
       /*port_disconnect (*/
         /*AUDIO_ENGINE->stereo_in->l,*/
@@ -434,7 +435,7 @@ track_set_recording (Track *   track,
       /*port_disconnect (*/
         /*AUDIO_ENGINE->midi_in,*/
         /*channel->midi_in);*/
-    }
+    /*}*/
 
   track->recording = recording;
 
@@ -761,6 +762,7 @@ track_add_region (
 
   if (add_lane)
     {
+      g_warn_if_fail (track->lanes[lane_pos]);
       track_lane_add_region (
         track->lanes[lane_pos],
         region);
@@ -928,7 +930,8 @@ track_free (Track * track)
 
 #undef _FREE_TRACK
 
-  channel_free (track->channel);
+  if (track->channel)
+    channel_free (track->channel);
 
   if (track->widget && GTK_IS_WIDGET (track->widget))
     gtk_widget_destroy (
