@@ -46,15 +46,12 @@ chord_key_draw_cb (
   cairo_t *cr,
   ChordKeyWidget * self)
 {
-  guint width, height;
-  GtkStyleContext *context;
-
-  context =
+  GtkStyleContext *context =
     gtk_widget_get_style_context (widget);
 
-  width =
+  int width =
     gtk_widget_get_allocated_width (widget);
-  height =
+  int height =
     gtk_widget_get_allocated_height (widget);
 
   gtk_render_background (
