@@ -31,7 +31,7 @@ G_DEFINE_TYPE (KnobWidget,
                knob_widget,
                GTK_TYPE_DRAWING_AREA)
 
-#define ARC_CUT_ANGLE 60
+#define ARC_CUT_ANGLE 60.f
 
 /**
  * Macro to get real value.
@@ -46,21 +46,25 @@ G_DEFINE_TYPE (KnobWidget,
  * MAcro to get real value from knob value.
  */
 #define REAL_VAL_FROM_KNOB(knob) \
-  (self->min + knob * (self->max - self->min))
+  (self->min + (float) knob * \
+   (self->max - self->min))
 
 /**
  * Converts from real value to knob value
  */
-#define KNOB_VAL_FROM_REAL(real) ((real - self->min) / (self->max - self->min))
+#define KNOB_VAL_FROM_REAL(real) \
+  (((float) real - self->min) / \
+   (self->max - self->min))
 
 /**
  * Sets real val
  */
 #define SET_REAL_VAL(real) \
   (self->type == KNOB_TYPE_NORMAL ? \
-   ((*self->setter)(self->object, real)) : \
+   ((*self->setter)(self->object, (float) real)) : \
    port_set_multiplier_by_index ( \
-     (Port *) self->object, self->dest_index, real))
+     (Port *) self->object, \
+     self->dest_index, (float) real))
 
 /**
  * Draws the knob.
@@ -74,89 +78,131 @@ draw_cb (
   GtkStyleContext * context =
     gtk_widget_get_style_context (widget);
 
-  guint width, height;
-  width = gtk_widget_get_allocated_width (widget);
-  height = gtk_widget_get_allocated_height (widget);
+  int width =
+    gtk_widget_get_allocated_width (widget);
+  int height =
+    gtk_widget_get_allocated_height (widget);
 
   gtk_render_background (
     context, cr, 0, 0, width, height);
   cairo_pattern_t* shade_pattern;
 
-  const float scale = width;
-  const float pointer_thickness = 3.0 * (scale/80);  //(if the knob is 80 pixels wide, we want a 3-pix line on it)
+  const float scale = (float) width;
+  /* if the knob is 80 pixels wide, we want a
+   * 3px line on it */
+  const float pointer_thickness =
+    3.f * (scale / 80.f);
 
-  const float start_angle = ((180 - ARC_CUT_ANGLE) * G_PI) / 180;
-  const float end_angle = ((360 + ARC_CUT_ANGLE) * G_PI) / 180;
+  const float start_angle =
+    ((180.f - ARC_CUT_ANGLE) * (float) G_PI) / 180.f;
+  const float end_angle =
+    ((360.f + ARC_CUT_ANGLE) * (float) G_PI) / 180.f;
 
-  const float value = KNOB_VAL_FROM_REAL (GET_REAL_VAL);
+  const float value =
+    KNOB_VAL_FROM_REAL (GET_REAL_VAL);
   const float value_angle = start_angle
     + value * (end_angle - start_angle);
-  const float zero_angle = start_angle + (self->zero * (end_angle - start_angle));
+  const float zero_angle =
+    start_angle +
+    (self->zero * (end_angle - start_angle));
 
-  float value_x = cos (value_angle);
-  float value_y = sin (value_angle);
+  float value_x = cosf (value_angle);
+  float value_y = sinf (value_angle);
 
-  float xc =  0.5 + width/ 2.0;
-  float yc = 0.5 + height/ 2.0;
+  float xc =  0.5f + (float) width / 2.0f;
+  float yc = 0.5f + (float) height / 2.0f;
 
-  cairo_translate (cr, xc, yc);  //after this, everything is based on the center of the knob
-
-  //get the knob color from the theme
-
-  float center_radius = 0.48*scale;
-  float border_width = 0.8;
+  /* after this, everything is based on the center
+   * of the knob */
+  cairo_translate (cr, (double) xc, (double) yc);
 
+  /* get the knob color from the theme */
+  float center_radius = 0.48f * scale;
+  float border_width = 0.8f;
 
   if (self->arc)
     {
-      center_radius = scale*0.33;
+      center_radius = scale * 0.33f;
 
-      float inner_progress_radius = scale*0.38;
-      float outer_progress_radius = scale*0.48;
-      float progress_width = (outer_progress_radius-inner_progress_radius);
-      float progress_radius = inner_progress_radius + progress_width/2.0;
+      float inner_progress_radius =
+        scale * 0.38f;
+      float outer_progress_radius =
+        scale * 0.48f;
+      float progress_width =
+        (outer_progress_radius -
+         inner_progress_radius);
+      float progress_radius =
+        inner_progress_radius + progress_width / 2.f;
 
       /* dark surrounding arc background */
-      cairo_set_source_rgb (cr, 0.3, 0.3, 0.3 );
-      cairo_set_line_width (cr, progress_width);
-      cairo_arc (cr, 0, 0, progress_radius, start_angle, end_angle);
+      cairo_set_source_rgb (
+        cr, 0.3, 0.3, 0.3 );
+      cairo_set_line_width (
+        cr, progress_width);
+      cairo_arc (
+        cr, 0, 0, progress_radius, start_angle,
+        end_angle);
       cairo_stroke (cr);
 
       //look up the surrounding arc colors from the config
       // TODO
 
       //vary the arc color over the travel of the knob
-      float intensity = fabsf (value - self->zero) / MAX(self->zero, (1.f - self->zero));
-      const float intensity_inv = 1.0 - intensity;
-      float r = intensity_inv * self->end_color.red   +
-                intensity * self->start_color.red;
-      float g = intensity_inv * self->end_color.green +
-                intensity * self->start_color.green;
-      float b = intensity_inv * self->end_color.blue  +
-                intensity * self->start_color.blue;
+      double intensity =
+        fabs ((double) value - (double) self->zero) /
+        MAX (
+          (double) self->zero,
+          (double) (1.f - self->zero));
+      const double intensity_inv =
+        1.0 - intensity;
+      double r =
+        intensity_inv * self->end_color.red   +
+        intensity * self->start_color.red;
+      double g =
+        intensity_inv * self->end_color.green +
+        intensity * self->start_color.green;
+      double b =
+        intensity_inv * self->end_color.blue  +
+        intensity * self->start_color.blue;
 
       //draw the arc
-      cairo_set_source_rgb (cr, r,g,b);
+      cairo_set_source_rgb (
+        cr, r, g, b);
       cairo_set_line_width (cr, progress_width);
       if (zero_angle > value_angle)
         {
-          cairo_arc (cr, 0, 0, progress_radius, value_angle, zero_angle);
+          cairo_arc (
+            cr, 0, 0, progress_radius,
+            value_angle, zero_angle);
         }
       else
         {
-          cairo_arc (cr, 0, 0, progress_radius, zero_angle, value_angle);
+          cairo_arc (
+            cr, 0, 0, progress_radius,
+            zero_angle, value_angle);
         }
       cairo_stroke (cr);
 
       //shade the arc
       if (!self->flat)
         {
-          shade_pattern = cairo_pattern_create_linear (0.0, -yc, 0.0,  yc);  //note we have to offset the pattern from our centerpoint
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 0.0, 1,1,1, 0.15);
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 0.5, 1,1,1, 0.0);
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 1.0, 1,1,1, 0.0);
-          cairo_set_source (cr, shade_pattern);
-          cairo_arc (cr, 0, 0, outer_progress_radius-1, 0, 2.0*G_PI);
+          /* note we have to offset the pattern from
+           * our centerpoint */
+          shade_pattern =
+            cairo_pattern_create_linear (
+              0.0, -yc, 0.0,  yc);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 0.0, 1,1,1, 0.15);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 0.5, 1,1,1, 0.0);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 1.0, 1,1,1, 0.0);
+          cairo_set_source (
+            cr, shade_pattern);
+          cairo_arc (
+            cr, 0, 0,
+            (double) outer_progress_radius - 1.0,
+            0, 2.0*G_PI);
           cairo_fill (cr);
           cairo_pattern_destroy (shade_pattern);
         }
@@ -183,46 +229,72 @@ draw_cb (
   if (!self->flat)
     {
       //knob shadow
-      cairo_save(cr);
-      cairo_translate(cr, pointer_thickness+1, pointer_thickness+1 );
+      cairo_save (cr);
+      cairo_translate (
+        cr, pointer_thickness+1,
+        pointer_thickness+1 );
       cairo_set_source_rgba (cr, 0, 0, 0, 0.1 );
-      cairo_arc (cr, 0, 0, center_radius-1, 0, 2.0*G_PI);
+      cairo_arc (
+        cr, 0, 0, center_radius-1, 0, 2.0*G_PI);
       cairo_fill (cr);
       cairo_restore(cr);
 
       //inner circle
 #define KNOB_COLOR 0, 90, 0, 0
-      cairo_set_source_rgba(cr, KNOB_COLOR); /* knob color */
-      cairo_arc (cr, 0, 0, center_radius, 0, 2.0*G_PI);
+      cairo_set_source_rgba (
+        cr, KNOB_COLOR); /* knob color */
+      cairo_arc (
+        cr, 0, 0, center_radius, 0, 2.0*G_PI);
       cairo_fill (cr);
 
       //gradient
       if (self->bevel)
         {
           //knob gradient
-          shade_pattern = cairo_pattern_create_linear (0.0, -yc, 0.0,  yc);  //note we have to offset the gradient from our centerpoint
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 0.0, 1,1,1, 0.2);
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 0.2, 1,1,1, 0.2);
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 0.8, 0,0,0, 0.2);
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 1.0, 0,0,0, 0.2);
+          shade_pattern =
+            cairo_pattern_create_linear (0.0, -yc, 0.0,  yc);  //note we have to offset the gradient from our centerpoint
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 0.0, 1,1,1, 0.2);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 0.2, 1,1,1, 0.2);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 0.8, 0,0,0, 0.2);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 1.0, 0,0,0, 0.2);
           cairo_set_source (cr, shade_pattern);
-          cairo_arc (cr, 0, 0, center_radius, 0, 2.0*G_PI);
+          cairo_arc (
+            cr, 0, 0, center_radius, 0, 2.0*G_PI);
           cairo_fill (cr);
           cairo_pattern_destroy (shade_pattern);
 
           //flat top over beveled edge
-          cairo_set_source_rgba (cr, 90, 0, 0, 0.5 );
-          cairo_arc (cr, 0, 0, center_radius-pointer_thickness, 0, 2.0*G_PI);
+          cairo_set_source_rgba (
+            cr, 90, 0, 0, 0.5 );
+          cairo_arc (
+            cr, 0, 0,
+            center_radius-pointer_thickness,
+            0, 2.0*G_PI);
           cairo_fill (cr);
         }
       else
         {
-          //radial gradient
-          shade_pattern = cairo_pattern_create_radial ( -center_radius, -center_radius, 1, -center_radius, -center_radius, center_radius*2.5  );  //note we have to offset the gradient from our centerpoint
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 0.0, 1,1,1, 0.2);
-          cairo_pattern_add_color_stop_rgba (shade_pattern, 1.0, 0,0,0, 0.3);
+          /* radial gradient
+           * note we have to offset the gradient
+           * from our centerpoint */
+          shade_pattern =
+            cairo_pattern_create_radial (
+              -center_radius, -center_radius,
+              1, -center_radius,
+              -center_radius,
+              center_radius*2.5f);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 0.0, 1,1,1, 0.2);
+          cairo_pattern_add_color_stop_rgba (
+            shade_pattern, 1.0, 0,0,0, 0.3);
           cairo_set_source (cr, shade_pattern);
-          cairo_arc (cr, 0, 0, center_radius, 0, 2.0*G_PI);
+          cairo_arc (
+            cr, 0, 0, center_radius,
+            0, 2.0*G_PI);
           cairo_fill (cr);
           cairo_pattern_destroy (shade_pattern);
         }
@@ -230,8 +302,10 @@ draw_cb (
   else
     {
         /* color inner circle */
-        cairo_set_source_rgba(cr, 70, 70, 70, 0.2);
-        cairo_arc (cr, 0, 0, center_radius, 0, 2.0*G_PI);
+        cairo_set_source_rgba (
+          cr, 70, 70, 70, 0.2);
+        cairo_arc (
+          cr, 0, 0, center_radius, 0, 2.0*G_PI);
         cairo_fill (cr);
     }
 
@@ -243,31 +317,42 @@ draw_cb (
   cairo_stroke (cr);
 
   //line shadow
-  if (!self->flat) {
-          cairo_save(cr);
-          cairo_translate(cr, 1, 1 );
-          cairo_set_source_rgba (cr, 0,0,0,0.3 );
-          cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
-          cairo_set_line_width (cr, pointer_thickness);
-          cairo_move_to (cr, (center_radius * value_x), (center_radius * value_y));
-          cairo_line_to (cr, ((center_radius*0.4) * value_x), ((center_radius*0.4) * value_y));
-          cairo_stroke (cr);
-          cairo_restore(cr);
-  }
+  if (!self->flat)
+    {
+      cairo_save(cr);
+      cairo_translate(cr, 1, 1 );
+      cairo_set_source_rgba (cr, 0,0,0,0.3 );
+      cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
+      cairo_set_line_width (cr, pointer_thickness);
+      cairo_move_to (
+        cr, (center_radius * value_x),
+        (center_radius * value_y));
+      cairo_line_to (
+        cr, ((center_radius*0.4f) * value_x),
+        ((center_radius*0.4f) * value_y));
+      cairo_stroke (cr);
+      cairo_restore(cr);
+    }
 
   //line
   cairo_set_source_rgba (cr, 1,1,1, 1 );
   cairo_set_line_cap (cr, CAIRO_LINE_CAP_ROUND);
   cairo_set_line_width (cr, pointer_thickness);
-  cairo_move_to (cr, (center_radius * value_x), (center_radius * value_y));
-  cairo_line_to (cr, ((center_radius*0.4) * value_x), ((center_radius*0.4) * value_y));
+  cairo_move_to (
+    cr, (center_radius * value_x),
+    (center_radius * value_y));
+  cairo_line_to (
+    cr, ((center_radius*0.4f) * value_x),
+    ((center_radius*0.4f) * value_y));
   cairo_stroke (cr);
 
-  //highlight if grabbed or if mouse is hovering over me
+  //highlight if grabbed or if mouse is hovering over
+  //me
   if (self->hover)
     {
       cairo_set_source_rgba (cr, 1,1,1, 0.12 );
-      cairo_arc (cr, 0, 0, center_radius, 0, 2.0*G_PI);
+      cairo_arc (
+        cr, 0, 0, center_radius, 0, 2.0*G_PI);
       cairo_fill (cr);
     }
 
@@ -316,9 +401,10 @@ drag_update (
     REAL_VAL_FROM_KNOB (
       clamp (
         KNOB_VAL_FROM_REAL (GET_REAL_VAL) +
-          0.004 * (
-            use_y ? offset_y - self->last_y :
-            offset_x - self->last_x),
+          0.004f * (
+            use_y ?
+            (float) (offset_y - self->last_y) :
+            (float) (offset_x - self->last_x)),
          1.0f, 0.0f)));
   self->last_x = offset_x;
   self->last_y = offset_y;
