@@ -377,24 +377,19 @@ ports_expander_widget_setup_track (
 {
   self->track = tr;
   self->owner_type = PORT_OWNER_TYPE_TRACK;
+  /*PortType in_type =*/
+    /*self->track->in_signal_type;*/
+  PortType out_type =
+    self->track->out_signal_type;
 
   switch (type)
     {
-    case PE_TRACK_PORT_TYPE_PREFADER:
+    case PE_TRACK_PORT_TYPE_SENDS:
       expander_box_widget_set_label (
         Z_EXPANDER_BOX_WIDGET (self),
-        _("Pre-Fader Sends"));
-      self->owner_type = PORT_OWNER_TYPE_FADER;
+        _("Sends"));
       self->flow = FLOW_OUTPUT;
-      self->type = TYPE_AUDIO;
-      break;
-    case PE_TRACK_PORT_TYPE_POSTFADER:
-      expander_box_widget_set_label (
-        Z_EXPANDER_BOX_WIDGET (self),
-        _("Post-Fader Sends"));
-      self->owner_type = PORT_OWNER_TYPE_FADER;
-      self->flow = FLOW_OUTPUT;
-      self->type = TYPE_AUDIO;
+      self->type = out_type;
       break;
     case PE_TRACK_PORT_TYPE_STEREO_IN:
       expander_box_widget_set_label (
@@ -437,17 +432,26 @@ ports_expander_widget_setup_track (
   PortConnectionsButtonWidget * pcb;
   switch (type)
     {
-    case PE_TRACK_PORT_TYPE_PREFADER:
-      ADD_SINGLE (
-        tr->channel->prefader.stereo_out->l);
-      ADD_SINGLE (
-        tr->channel->prefader.stereo_out->r);
+    case PE_TRACK_PORT_TYPE_SENDS:
+      if (out_type == TYPE_AUDIO)
+        {
+          ADD_SINGLE (
+            tr->channel->prefader.stereo_out->l);
+          ADD_SINGLE (
+            tr->channel->prefader.stereo_out->r);
+          ADD_SINGLE (
+            tr->channel->fader.stereo_out->l);
+          ADD_SINGLE (
+            tr->channel->fader.stereo_out->r);
+        }
+      else if (out_type == TYPE_EVENT)
+        {
+          ADD_SINGLE (
+            tr->channel->prefader.midi_out);
+          ADD_SINGLE (
+            tr->channel->fader.midi_out);
+        }
       break;
-    case PE_TRACK_PORT_TYPE_POSTFADER:
-      ADD_SINGLE (
-        tr->channel->fader.stereo_out->l);
-      ADD_SINGLE (
-        tr->channel->fader.stereo_out->r);
       break;
     case PE_TRACK_PORT_TYPE_STEREO_IN:
       ADD_SINGLE (
